

set -ex



nc-config --all
test -f ${PREFIX}/lib/libnetcdf.a
test -f ${PREFIX}/lib/libnetcdf.so
ncdump -h "http://oos.soest.hawaii.edu/thredds/dodsC/hioos/model/atm/ncep_pac/NCEP_Pacific_Atmospheric_Model_best.ncd"
ncdump -h "http://oos.soest.hawaii.edu/thredds/dodsC/usgs_dem_10m_tinian"
conda inspect linkages -p $PREFIX $PKG_NAME
exit 0
